@@ -1,6 +1,6 @@
 # coding: utf-8
 
-# © Copyright IBM Corporation 2020.
+# © Copyright IBM Corporation 2020, 2022.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -63,8 +63,8 @@ class CouchDbSessionTokenManager(TokenManager):
             method='POST',
             url=self.url + "/_session",
             headers=self.headers,
-            data={
-                'name': self.username,
+            json={
+                'username': self.username,
                 'password': self.password,
             }
         )
